Extracts the estimated regression coefficients from a fitted Generalized
Kumaraswamy (GKw) regression model object of class "gkwreg". This is
an S3 method for the generic coef function.
# S3 method for gkwreg
coef(object, ...)A named numeric vector containing the estimated regression coefficients
for all modeled parameters. The names indicate the parameter (e.g., alpha,
beta) and the corresponding predictor variable (e.g., (Intercept), x1).
An object of class "gkwreg", typically the result of a
call to gkwreg.
Additional arguments, currently ignored by this method.
Lopes, J. E.
This function provides the standard way to access the estimated regression
coefficients from a model fitted with gkwreg. It simply
extracts the coefficients component from the fitted model object.
The function coefficients is an alias for this function.