dot-format_coefficient_names: Format Coefficient Names Based on Family and Model Matrices

.format_coefficient_namesR Documentation

Format Coefficient Names Based on Family and Model Matrices

Description

Format Coefficient Names Based on Family and Model Matrices

Usage

.format_coefficient_names(param_names, model_data, param_positions)

Arguments

param_names

Names of parameters for the family

model_data

Model data list including matrices

param_positions

Parameter position mapping for the family

Value

Vector of formatted coefficient names


gkwreg documentation built on Aug. 24, 2026, 9:10 a.m.