Learn R Programming

gkwreg (version 2.1.6)

family.gkwreg: Extract Family from GKw Regression Model

Description

Extracts the family specification from a fitted Generalized Kumaraswamy regression model object.

Usage

# S3 method for gkwreg
family(object, ...)

Value

A character string indicating the family used in the model.

Arguments

object

An object of class "gkwreg".

...

Currently not used.

Author

Lopes, J. E.

See Also

gkwreg

Examples

Run this code
# \donttest{
data(GasolineYield)
fit <- gkwreg(yield ~ batch + temp, data = GasolineYield, family = "kw")
family(fit)
# }

Run the code above in your browser using DataLab