Learn R Programming

gkwreg (version 2.1.6)

nobs.gkwreg: Number of Observations for GKw Regression Models

Description

Extracts the number of observations from a fitted Generalized Kumaraswamy regression model.

Usage

# S3 method for gkwreg
nobs(object, ...)

Value

Integer representing the number of observations used in model fitting.

Arguments

object

An object of class "gkwreg", typically obtained from gkwreg.

...

Currently not used.

Author

Lopes, J. E.

See Also

gkwreg

Examples

Run this code
# \donttest{
data(GasolineYield)
fit <- gkwreg(yield ~ batch + temp, data = GasolineYield, family = "kw")
nobs(fit)
# }

Run the code above in your browser using DataLab