powered by
Extracts the family specification from a fitted Generalized Kumaraswamy regression model object.
# S3 method for gkwreg family(object, ...)
A character string indicating the family used in the model.
An object of class "gkwreg".
"gkwreg"
Currently not used.
Lopes, J. E.
gkwreg
# \donttest{ data(GasolineYield) fit <- gkwreg(yield ~ batch + temp, data = GasolineYield, family = "kw") family(fit) # }
Run the code above in your browser using DataLab