powered by
Extracts the number of observations from a fitted Generalized Kumaraswamy regression model.
# S3 method for gkwreg nobs(object, ...)
Integer representing the number of observations used in model fitting.
An object of class "gkwreg", typically obtained from gkwreg.
"gkwreg"
gkwreg
Currently not used.
Lopes, J. E.
# \donttest{ data(GasolineYield) fit <- gkwreg(yield ~ batch + temp, data = GasolineYield, family = "kw") nobs(fit) # }
Run the code above in your browser using DataLab